@@ -3,10 +3,10 @@ use strict;
 use warnings;
 use warnings::register;
 
-use v5.006;
+use 5.006;
 
 # ABSTRACT: An extension of the File::stat module, provides additional methods.
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 #pod =for test_synopsis
 #pod my ($st, $file);
@@ -391,15 +391,37 @@ sub isSocket {
 #pod file (handle) I<is> tested the I<first> time the operator is
 #pod used. After the first time, the initial result is re-used.
 #pod
-#pod =method Unary "" (stringification) and other operators
+#pod =method Unary C<""> (stringification)
 #pod
-#pod The unary "" operator is overloaded to return the the device and inode
-#pod numbers separated by a C<.> (C<I<dev>.I<ino>>). This yields a uniqe file identifier.
+#pod The unary C<""> (stringification) operator is overloaded to return the the device and inode
+#pod numbers separated by a C<.> (C<I<dev>.I<ino>>). This yields a uniqe file identifier (as string).
 #pod
-#pod All other operators are automagically generated based on this
-#pod representation, meaning you can easily compare two
-#pod C<File::stat::Extra> objects to see if they are the same (hardlinked)
-#pod file.
+#pod =method Comparison operators C<< <=> >>, C<cmp>, and C<~~>
+#pod
+#pod The comparison operators use the string representation of the
+#pod C<File::stat::Extra> object. So, to see if two C<File::stat::Extra>
+#pod object point to the same (hardlinked) file, you can simply say
+#pod something like this:
+#pod
+#pod     print 'Same file' if $ob1 == $ob2;
+#pod
+#pod For objects created from an C<stat> of a symbolic link, the actual
+#pod I<destination> of the link is used in the comparison! If you want to
+#pod compare the actual symnlink file, use C<lstat> instead.
+#pod
+#pod Note: All comparisons (also the numeric versions) are performed on the
+#pod full stringified versions of the object. This to prevent files on the
+#pod same device, but with an inode number ending in a zero to compare
+#pod equally while they aren't (e.g., 5.10 and 5.100 compare equal
+#pod numerically but denote a different file).
+#pod
+#pod Note: the smartmatch C<~~> operator is obly overloaded on Perl version
+#pod 5.10 and above.
+#pod
+#pod =method Other operators
+#pod
+#pod As the other operators (C<+>, C<->, C<*>, etc.) are meaningless, they
+#pod have not been overloaded and will cause a run-time error.
 #pod
 #pod =cut
 
@@ -442,24 +464,43 @@ my %op = (
     B => sub { defined $_[0][4] ? $_[0][4] : $_[0][4] = (-B $_[0]->file) || 0 },
 );
 
-use overload
-    fallback => 1,
+sub _filetest {
+    my ($s, $op) = @_;
+    if ($op{$op}) {
+        return $op{$op}->($s);
+    } else {
+        # We should have everything covered so this is just a safegauard
+        Carp::croak "-$op is not implemented on a File::stat::Extra object";
+    }
+}
 
-    # File test operators
-    -X => sub {
-        my ($s, $op) = @_;
-        if ($op{$op}) {
-            return $op{$op}->($s);
-        } else {
-             # We should have everything covered so this is just a safegauard
-            Carp::croak "-$op is not implemented on a File::stat::Extra object";
-        }
-    },
+sub _dev_ino {
+    return $_[0]->dev . "." . $_[0]->ino;
+}
+
+sub _compare {
+    my $va = shift;
+    my $vb = shift;
+    my $swapped = shift;
+    ($vb, $va) = ($va, $vb) if $swapped;
+
+    return "$va" cmp "$vb"; # Force stringification when comparing
+}
+
+use overload
+    # File test operators (as of Perl v5.12)
+    $^V >= 5.012 ? (-X => \&_filetest) : (),
 
     # Unary "" returns the object as "dev.ino", this should be a
-    # unique number so one can test file equality easily (hard links
-    # are equal)
-    '""' => sub { $_[0]->dev . "." . $_[0]->ino },
+    # unique string for each file.
+    '""' => \&_dev_ino,
+
+    # Comparison is done based on the unique string created with the stringification
+    '<=>' => \&_compare,
+    'cmp' => \&_compare,
+
+    # Smartmatch as of Perl v5.10
+    $^V >= 5.010 ? ('~~' => \&_compare) : (),
 
     ;
 
@@ -477,7 +518,7 @@ File::stat::Extra - An extension of the File::stat module, provides additional m
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -671,15 +712,37 @@ Note: in case of the special file tests C<-t>, C<-T>, and C<-B>, the
 file (handle) I<is> tested the I<first> time the operator is
 used. After the first time, the initial result is re-used.
 
-=head2 Unary "" (stringification) and other operators
+=head2 Unary C<""> (stringification)
 
-The unary "" operator is overloaded to return the the device and inode
-numbers separated by a C<.> (C<I<dev>.I<ino>>). This yields a uniqe file identifier.
+The unary C<""> (stringification) operator is overloaded to return the the device and inode
+numbers separated by a C<.> (C<I<dev>.I<ino>>). This yields a uniqe file identifier (as string).
 
-All other operators are automagically generated based on this
-representation, meaning you can easily compare two
-C<File::stat::Extra> objects to see if they are the same (hardlinked)
-file.
+=head2 Comparison operators C<< <=> >>, C<cmp>, and C<~~>
+
+The comparison operators use the string representation of the
+C<File::stat::Extra> object. So, to see if two C<File::stat::Extra>
+object point to the same (hardlinked) file, you can simply say
+something like this:
+
+    print 'Same file' if $ob1 == $ob2;
+
+For objects created from an C<stat> of a symbolic link, the actual
+I<destination> of the link is used in the comparison! If you want to
+compare the actual symnlink file, use C<lstat> instead.
+
+Note: All comparisons (also the numeric versions) are performed on the
+full stringified versions of the object. This to prevent files on the
+same device, but with an inode number ending in a zero to compare
+equally while they aren't (e.g., 5.10 and 5.100 compare equal
+numerically but denote a different file).
+
+Note: the smartmatch C<~~> operator is obly overloaded on Perl version
+5.10 and above.
+
+=head2 Other operators
+
+As the other operators (C<+>, C<->, C<*>, etc.) are meaningless, they
+have not been overloaded and will cause a run-time error.
 
 =for test_synopsis my ($st, $file);
 
